<?php

###############################################################################
# 
# This is the czech language page for GeekLog!
#
# Copyright (C) 2002 hermes_trismegistos
# hermes_trismegistos@post.cz
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

$LANG_CHARSET = 'UTF-8';

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

###############################################################################
# USER PHRASES - These are file phrases used in end user scripts
###############################################################################

###############################################################################
# lib-common.php

$LANG01 = array(
    1 => 'Publikoval :',
    2 => '<b>Číst celé</b>',
    3 => 'komentářů',
    4 => 'Editovat',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => 'Administrátorské funkce:',
    10 => 'Příspěvky',
    11 => 'Články',
    12 => 'Bloky',
    13 => 'Sekce',
    14 => '',
    15 => '',
    16 => '',
    17 => 'Uživatelé',
    18 => 'SQL dotaz',
    19 => '<b>Odhlásit</b>',
    20 => 'Informace o uživateli:',
    21 => 'Uživatel',
    22 => 'Uživatelův ID',
    23 => 'Úroveň práv',
    24 => 'Anonymní host',
    25 => 'Odpověď',
    26 => ' Následující komentáře jsou názorem jejich vkladatele. <br' . XHTML . '>Weblog neručí za to co je zde napsáno.',
    27 => 'Naposledy přidáno',
    28 => 'Smazat',
    29 => 'Nejsou žádné komentáře.',
    30 => 'Starší články',
    31 => 'HTML tagy povoleny:',
    32 => 'Chyba, neplatné uživatelské jméno',
    33 => 'Chyba, nepovolený zápis do log fajlu',
    34 => 'Chyba',
    35 => 'Odhlásit',
    36 => ' - ',
    37 => 'Bez článků',
    38 => 'Content Syndication',
    39 => 'Obnovit',
    40 => '',
    41 => 'Hosté',
    42 => 'Publikováno:',
    43 => 'Odpovědět na toto',
    44 => 'Nadřazený',
    45 => 'MySQL Error Number',
    46 => 'MySQL Error Message',
    47 => 'Uživatelské menu',
    48 => 'Informace o účtu',
    49 => 'Vlastní nastavení',
    50 => 'Error with SQL statement',
    51 => 'help',
    52 => 'Nové',
    53 => 'Administrace',
    54 => 'Nelze otevřít soubor.',
    55 => 'Nastala chyba - ',
    56 => 'Hlasovat',
    57 => 'Heslo',
    58 => 'Přihlásit',
    59 => "Nemáte zatím účet?  Přihlašte se jako <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"><b>Nový&nbsp;uživatel</b></a>",
    60 => 'Okomentovat',
    61 => 'Nový uživatel',
    62 => 'slov',
    63 => 'Nastavení komentářů',
    64 => 'Poslat emailem',
    65 => 'Verze pro tiskárnu',
    66 => '',
    67 => 'Vítejte na ',
    68 => 'home',
    69 => 'kontakt',
    70 => 'hledat',
    71 => 'příspěvky',
    72 => 'odkazy',
    73 => '',
    74 => '',
    75 => 'rozšířené hledání',
    76 => 'statistika',
    77 => 'Pluginy',
    78 => '',
    79 => 'Co je nového',
    80 => 'článků za posledních',
    81 => 'článek za posledních',
    82 => 'hodin',
    83 => 'KOMENTÁŘE',
    84 => '',
    85 => 'za posledních 48 hodin',
    86 => 'Nejsou nové komentáře',
    87 => 'za poslední 2 týdny',
    88 => '',
    89 => '',
    90 => 'Homepage',
    91 => 'Stránka vytvořena za',
    92 => 'sekund&nbsp;',
    93 => 'Copyright',
    94 => 'Všechna práva a ochranné známky na těchto stránkách patří jejich vlastníkům.',
    95 => 'Používáme',
    96 => 'Skupiny',
    97 => 'Word List',
    98 => 'Pluginy',
    99 => 'ČLÁNKY',
    100 => 'Nejsou nové články',
    101 => '',
    102 => '',
    103 => 'DB zálohy',
    104 => '-',
    105 => 'Emailový démon',
    106 => 'Zhlédnuto',
    107 => 'Test Verze GL',
    108 => 'Smazat cache',
    109 => 'Report abuse',
    110 => 'Report this post to the site admin',
    111 => '',
    112 => 'Registered Users',
    113 => 'Documentation',
    114 => 'TRACKBACKS',
    115 => 'No new trackback comments',
    116 => 'Trackback',
    117 => 'Directory',
    118 => 'Please continue reading on the next page:',
    119 => "Lost your <a href=\"{$_CONF['site_url']}/users.php?mode=getpassword\" rel=\"nofollow\">password</a>?",
    120 => 'Permanent link to this comment',
    121 => 'Comments (%d)',
    122 => 'Trackbacks (%d)',
    123 => 'All HTML is allowed',
    124 => 'Click to delete all checked items',
    125 => 'Are you sure you want to Delete all checked items?',
    126 => 'Select or de-select all items',
    127 => 'Permalink',
    128 => 'Login with OpenID:',
    129 => 'Configuration',
    130 => 'Webservices'
);

###############################################################################
# comment.php

$LANG03 = array(
    1 => 'Vložit komentář',
    2 => 'Typ komentáře',
    3 => 'Odhlásit',
    4 => 'Vytvořit účet',
    5 => 'Uživatel',
    6 => 'Tato stránka vyžaduje přihlášení pro vložení komentáře, prosím přihlašte se.  Pokud nemáte účet - můžete si ho vytvořit.',
    7 => 'Váš poslední komentář vložen před ',
    8 => " sekundami.  Tato stránka vyžaduje prodlevu {$_CONF['commentspeedlimit']} sekund mezi komentáři.",
    9 => 'Komentář',
    10 => 'Send Report',
    11 => 'Vložit komentář',
    12 => 'Prosím vyplňte Titulek a Komentář, jinak nelze vložit.',
    13 => 'Vaše info',
    14 => 'Náhled',
    15 => 'Report this post',
    16 => 'Titulek',
    17 => 'Chyba',
    18 => 'Důležité',
    19 => 'Prosím vkládejte komentáře do správné sekce.',
    20 => 'Komentáře vkládejte pokud možno ve správném pořadí.',
    21 => 'Přečtěte si prosím nejdříve komentáře ostatních uživatelů, aby nedocházelo k duplicitě.',
    22 => 'Použijte titulek, který vložil systém.',
    23 => 'Váš email nebude publikován!',
    24 => 'Anonymní host',
    25 => 'Are you sure you want to report this post to the site admin?',
    26 => '%s reported the following abusive comment post:',
    27 => 'Abuse report',
    28 => 'Preview Changes',
    29 => 'Submit Changes',
    30 => 'Edited on',
    31 => 'by',
    32 => 'Editing a Comment',
    33 => 'Editing a Comment Submission',
    34 => 'Preview Submission Changes',
    35 => 'Save Changes to Queue',
    36 => 'Notify me of new replies',
    37 => 'New Comment Reply',
    38 => 'A reply has been made to your comment \'%s\'.',
    39 => 'You may view the comment thread at the following address:',
    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
    41 => 'Hello %s,',
    42 => 'Unsubscribe',
    43 => 'Unsubscribe from reply notifications',
    44 => 'Your Name'
);

###############################################################################
# users.php

$LANG04 = array(
    1 => 'Uživatelský profil:',
    2 => 'Přihlašovací jméno',
    3 => 'Jméno',
    4 => 'Heslo',
    5 => 'Email',
    6 => 'Homepage',
    7 => 'O vás',
    8 => 'PGP klíč',
    9 => 'Uložit změny',
    10 => 'Posledních 10 comentářů uživatele',
    11 => 'Bez komentářů uživatele',
    12 => 'Uživatelské nastavení:',
    13 => 'Posílat na konci každého dne výtah z weblogu emailem',
    14 => 'Toto heslo bylo náhodně vygenerováno systémem. Doporučuje se změnit co nejdříve. Pro změnu hesla se přihlašte a změnte si ho poté v menu Informace o účtu v Uživatelském rozhraní.',
    15 => "Váš {$_CONF['site_name']} účet byl vytvořen. Můžete se přihlásit, níže jsou Vaše přihlašovací data. Prosím uschovejt si tento email pro budoucí reference.",
    16 => 'Informace o účtu',
    17 => 'Účet neexistuje',
    18 => 'Email se zdá být v nesprávném formátu',
    19 => 'Uživatel nebo email již existuje',
    20 => 'Email se zdá být v nesprávném formátu',
    21 => 'Chyba',
    22 => "Registrace na {$_CONF['site_name']}!",
    23 => "Anonymní uživatelé - Hosté nemohou například komentovat či přidávat články.<br" . XHTML . ">Vytvoření účtu Vám umožní využívat všech funkcí na {$_CONF['site_name']}. <br" . XHTML . ">Vaše emailová adresa nebude <b><i>nikdy a nikde</i></b> zveřejněna na těchto stránkách.",
    24 => 'Vaše heslo bude posláno na vámi zadanou emailovou adresu.',
    25 => 'Zapomenuté heslo?',
    26 => 'Vložte Vaše přihlašovací jméno a klepněte na Poslat-heslo a nové heslo Vám bude zasláno na Vámi zadanou emailovou adresu.',
    27 => 'Registrovat nyní!',
    28 => 'Poslat-heslo',
    29 => 'odhlášen od',
    30 => 'přihlášen od',
    31 => 'Tato funkce vyžaduje přihlášení',
    32 => 'Podpis',
    33 => 'Nezobrazí se veřejně',
    34 => 'Toto je vaše pravé jméno',
    35 => 'Jen pro změnu hesla',
    36 => 'Na začátku s http://',
    37 => 'Bude použit v komentářích',
    38 => 'Toto je o Vás! Kdokoli si to může přečíst',
    39 => 'Váš veřejný PGP klíč',
    40 => 'Bez ikon Sekcí',
    41 => 'Chci být Moderátorem sekce',
    42 => 'Formát data',
    43 => 'Maximální počet článků',
    44 => 'Bez bloků',
    45 => 'Vlastní nastavení pro',
    46 => 'Bez těchto položek pro',
    47 => 'Nastavení bloků pro',
    48 => 'Sekce',
    49 => 'Nezobrazovat ikony',
    50 => 'Odškrtněte pokud vás nezajímá',
    51 => 'Jen novinky',
    52 => 'Systémové nastavení - ',
    53 => 'Dostávat články na konci dne emailem',
    54 => 'Zaškrtněte to co nechcete zobrazovat.',
    55 => 'Pokud necháte odškrtlé, bude použito původní nastavení - to co je tučně bude zobrazováno.  Pro vlastní nastavení zaškrtněte jen to co chcete zobrazovat.',
    56 => 'Autoři',
    57 => 'Nastavení zobrazování položek pro',
    58 => 'Řazení',
    59 => 'Maximální počet komentářů',
    60 => 'Jak chcete zobrazovat komentáře?',
    61 => 'Nejnovější nebo nejstarší nejdříve?',
    62 => 'Systémové nastavení - 100',
    63 => "Vaše heslo bude posláno na vámi zadanou emailovou adresu. Postupujte podle zaslaných instrukcí pro přihlášení do {$_CONF['site_name']}",
    64 => 'Nastavení komentářů pro',
    65 => 'Zkuste se přihlásit znovu',
    66 => "Spletl jste se v zadání.  Prosím zkuste to znovu. Nebo jste  <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"><b>nový uživatel</b></a>?",
    67 => 'Uživatelem od',
    68 => 'Pamatovat si mne',
    69 => 'Jak dlouho si Vás systém bude pamatovat.',
    70 => "Přizpůsobení vzhledu a obsahu {$_CONF['site_name']}",
    71 => "Přizpůsobení vzhledu na {$_CONF['site_name']} vám umožní nastavit si vlastní vzhled a řazení položek nezávisle na nastavení pro hosty.  Pro tato nastavení se musíte <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">přihlásit</a> na {$_CONF['site_name']}. <br" . XHTML . "> Jste uživatelem?  Pak použijte přihlašovací formulář vlevo!",
    72 => 'Grafické téma',
    73 => 'Jazyk',
    74 => 'Vyberte jak má weblog vypadat',
    75 => 'Zasílání sekcí',
    76 => 'Tyto sekce vám budou zasílána emailem koncem každého dne. Prosím vybírejte jen sekce, které vás zajímají!',
    77 => 'Foto',
    78 => 'Přidá Vaše foto (do velikosti 96x96px)!',
    79 => 'Zaškrtnout pro smazání fota',
    80 => 'Přihlásit',
    81 => 'Zaslat email',
    82 => 'Posledních 10 článků uživatele',
    83 => 'Publikační statistika uživatele',
    84 => 'Celkově publikací:',
    85 => 'Celkově komentářů:',
    86 => 'Najít vše od',
    87 => 'Your login name',
    88 => "Someone (possibly you) has requested a new password for your account \"%s\" on {$_CONF['site_name']}, <{$_CONF['site_url']}>.\n\nIf you really want this action to be taken, please click on the following link:\n\n",
    89 => "If you do not want this action to be taken, simply ignore this message and the request will be disregarded (your password will remain unchanged).\n\n",
    90 => 'You can enter a new password for your account below. Please note that your old password is still valid until you submit this form.',
    91 => 'Set New Password',
    92 => 'Enter New Password',
    93 => 'Your last request for a new password was %d seconds ago. This site requires at least %d seconds between password requests.',
    94 => 'Delete Account "%s"',
    95 => 'Click the "delete account" button below to remove your account from our database. Please note that any stories and comments you posted under this account will <strong>not</strong> be deleted but show up as being posted by "Anonymous".',
    96 => 'delete account',
    97 => 'Confirm Account Deletion',
    98 => 'Are you sure you want to delete your account? By doing so, you will not be able to log into this site again (unless you create a new account). If you are sure, click "delete account" again on the form below.',
    99 => 'Privacy Options for',
    100 => 'Email from Admin',
    101 => 'Allow email from Site Admins',
    102 => 'Email from Users',
    103 => 'Allow email from other users',
    104 => 'Show Online Status',
    105 => 'Show up in Who\'s Online block',
    106 => 'Location',
    107 => 'Shown in your public profile',
    108 => 'Confirm new password',
    109 => 'Enter the New password again here',
    110 => 'Current Password',
    111 => 'Please enter your Current password',
    112 => 'You have exceeded the number of allowed login attempts.  Please try again later.',
    113 => 'Login Attempt Failed',
    114 => 'Account Disabled',
    115 => 'Your account has been disabled, you may not login. Please contact an Administrator.',
    116 => 'Account Awaiting Activation',
    117 => 'Your account is currently awaiting activation by an administrator. You will not be able to login until your account has been approved.',
    118 => "Your {$_CONF['site_name']} account has now been activated by an administrator. You may now login to the site at the url below using your username (<username>) and password as previously emailed to you.",
    119 => 'If you have forgotten your password, you may request a new one at this url:',
    120 => 'Account Activated',
    121 => 'Service',
    122 => 'Sorry, new user registration is disabled',
    123 => "Are you a <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">new user</a>?",
    124 => 'Confirm Email',
    125 => 'You have to enter the same email address in both fields!',
    126 => 'Please repeat for confirmation',
    127 => 'To change any of these settings, you will have to enter your current password.',
    128 => 'Your Name',
    129 => 'Password &amp; Email',
    130 => 'About You',
    131 => 'Daily Digest Options',
    132 => 'Daily Digest Feature',
    133 => 'Comment Display',
    134 => 'Comment Options',
    135 => '<li>Default mode for how comments will be displayed</li><li>Default order to display comments</li><li>Set maximum number of comments to show - default is 100</li>',
    136 => 'Exclude Topics and Authors',
    137 => 'Filter Story Content',
    138 => 'Misc Settings',
    139 => 'Layout and Language',
    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics</li><li>Set the maximum number of stories to show per page</li><li>Set your theme, timezone and preferred date format</li>',
    141 => 'Privacy Settings',
    142 => 'The default setting is to allow users & admins to email fellow site members and show your status as online. Un-check these options to protect your privacy.',
    143 => 'Filter Block Content',
    144 => 'Show & hide boxes',
    145 => 'Your Public Profile',
    146 => 'Password and email',
    147 => 'Edit your account password, email and autologin feature. You will need to enter the same password or email address twice as a confirmation.',
    148 => 'User Information',
    149 => 'Modify your user information that will be shown to other users.<li>The signature will be added to any comments or forum posts you made</li><li>The BIO is a brief summary of yourself to share</li><li>Share your PGP Key</li>',
    150 => 'Warning: Javascript recommended for enhanced functionality',
    156 => 'Delete Account',
    157 => 'Delete Option',
    158 => 'Time Zone',
    159 => 'This email was generated automatically. Please do not reply to this email.',
    160 => '(max. %d x %d pixels, %d bytes; %s)',
    161 => 'will be scaled down',
    162 => 'will not be scaled',
    163 => 'Re-Authentication Failed',
    164 => 'You have exceeded the number of allowed attempts for re-authentication. The operation has been aborted and your recent changes were lost, sorry.',
    165 => 'Use Advanced Editor'
);

###############################################################################
# Customize if need to modify the Tabbed navbar MyAccount panels used.
# Array index key matches preference div id

$LANG_MYACCOUNT = array(
    'pe_preview' => 'Preview',
    'pe_namepass' => 'Username &amp; Password',
    'pe_userinfo' => 'About You',
    'pe_layout' => 'Layout &amp; Language',
    'pe_content' => 'Content',
    'pe_privacy' => 'Privacy'
);

###############################################################################
# index.php

$LANG05 = array(
    1 => 'Nic nového k zobrazení',
    2 => 'Žádné nové články k zobrazení.  Možná nejsou žádné novinky, nebo jste zadali špatné podmínky filtrování',
    3 => ' pro sekci %s',
    4 => 'Nejnovější článek',
    5 => 'Další',
    6 => 'Předešlé',
    7 => 'First',
    8 => 'Last'
);

###############################################################################
# profiles.php

$LANG08 = array(
    1 => 'Nastala chyba při odesílání emailu, zkuste to prosím znovu.',
    2 => 'Zpráva úspěšně odeslána.',
    3 => 'Zkontrolujte si prosím správnost emailové adresy.',
    4 => 'Prosím vyplňte všechna pole formuláře.',
    5 => 'Chyba: neexistující uživatel.',
    6 => 'Vznikla chyba.',
    7 => 'Uživatelský profil ',
    8 => 'Jméno',
    9 => 'URL stránek uživatele',
    10 => 'Poslat email uživateli ',
    11 => 'Vaše jméno:',
    12 => 'Poslat na:',
    13 => 'Hlavička:',
    14 => 'Zpráva:',
    15 => 'Použité HTML tagy nebudou změněny.<br' . XHTML . '>',
    16 => 'Poslat zprávu',
    17 => 'Poslat článek mailem',
    18 => 'Komu',
    19 => 'Kam',
    20 => 'Od koho',
    21 => 'Email odesilatele',
    22 => 'Prosím vyplňte všechna pole formuláře.',
    23 => "Tento email Vám byl poslán %s z %s protože si tento uživatel myslí, že by Vás mohl zaujmut.  Bylo publikováno na {$_CONF['site_url']}.   Toto NENÍ SPAM a Vaše emailová adresa nebyla nikde uložena a nebude tudíž použita k jakýmkoli účelům.",
    24 => 'Komentář k článku na',
    25 => 'Musíte být přihlášen jako uživatel pro použití této funkce weblogu.<br' . XHTML . '>  Touto restrikcí se předchází zneužití systému k spammingu!',
    26 => 'Tento formulář umožňuje zaslat email vybranému uživateli.  Vyplňte prosím všechna pole.',
    27 => 'Krátká zpráva',
    28 => '%s napsáno: ',
    29 => "Toto jsou denní novinky z {$_CONF['site_name']} pro ",
    30 => ' Denní novinky pro ',
    31 => 'Titulek',
    32 => 'Datum',
    33 => 'Celý článek si můžete přečíst na ',
    34 => 'Konec zprávy',
    35 => 'Sorry, this user prefers not to receive any emails.',
    36 => 'Copy:',
    37 => 'Send me a copy of this email',
    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:",
    39 => 'Your last message was ',
    40 => " seconds ago.  This site requires at least {$_CONF['speedlimit']} seconds between sending messages"
);

###############################################################################
# search.php

$LANG09 = array(
    1 => 'rozšířené hledání',
    2 => 'Klíčová slova',
    3 => 'Sekce',
    4 => 'Vše',
    5 => 'Typ',
    6 => 'Články',
    7 => 'Komentáře',
    8 => 'Autoři',
    9 => 'Vše',
    10 => 'Hledání',
    11 => 'Výsledky hledání',
    12 => 'odpovídající filtru',
    13 => 'Výsledky hledání: nic neodpovídá zadanému filtru',
    14 => 'Žádné výsledky neodpovídají zadanému filtru',
    15 => 'Prosím zkuste znovu.',
    16 => 'Titulek',
    17 => 'Datum',
    18 => 'Autor',
    19 => "Prohledat celou databázi nových i archivních položek na {$_CONF['site_name']}",
    20 => 'Datum',
    21 => 'do',
    22 => '(Formát data RRRR-MM-DD)',
    23 => 'Zhlédnuto',
    24 => 'Nalezeno',
    25 => 'filtru odpovídajících z celkem ',
    26 => 'položek během',
    27 => 'sekund',
    28 => 'Žádný článek nebo komentář neodpovídá zadanému filtru',
    29 => 'Výsledky vyhledávání článků a komentářů',
    30 => '',
    31 => 'This plug-in returned no matches',
    32 => '',
    33 => 'URL',
    34 => 'Umístění',
    35 => 'Celý den',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => 'Alespoň 3 znaky v poli vyhledávání.',
    42 => 'Prosím zadávejte datum v tomto formátu: RRRR-MM-DD (rok-měsíc-den).',
    43 => 'exact phrase',
    44 => 'all of these words',
    45 => 'any of these words',
    46 => 'Next',
    47 => 'Previous',
    48 => 'Author',
    49 => 'Date',
    50 => 'Hits',
    51 => '',
    52 => 'Location',
    53 => 'Story Results',
    54 => 'Comment Results',
    55 => 'the phrase',
    56 => 'AND',
    57 => 'OR',
    58 => 'More results &gt;&gt;',
    59 => 'Results',
    60 => 'per page',
    61 => 'Refine search',
    62 => '#',
    63 => 'Description',
    64 => 'Showing %1$d - %2$d of %3$d results',
    65 => 'Story',
    66 => 'Comment',
    67 => 'Show %d Results',
    68 => 'Sort By',
    69 => 'Titles Only',
    70 => 'Not available ...',
    71 => 'asc',
    72 => 'desc'
);

###############################################################################
# stats.php

$LANG10 = array(
    1 => 'Celková statistika stránek',
    2 => 'Souhrn požadavků na systém',
    3 => 'Články(komentáře) v systému',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Top Ten články',
    8 => 'Titulek článku',
    9 => 'Zhlédnuto',
    10 => 'Žádné články zde nejsou.',
    11 => 'Top Ten komentovaných článků',
    12 => 'Komentáře',
    13 => 'Žádné komentované články zde nejsou.',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '',
    22 => 'Top Ten emailem zaslaných článků',
    23 => 'Zasláno emailem',
    24 => 'Žádné emailem poslané články zde nejsou.',
    25 => 'Top Ten Trackback Commented Stories',
    26 => 'No trackback comments found.',
    27 => 'Number of active users',
    28 => '',
    29 => '',
    30 => 'Hits',
    31 => ''
);

###############################################################################
# article.php

$LANG11 = array(
    1 => 'Související',
    2 => 'Poslat mailem',
    3 => 'Verze pro tiskárnu',
    4 => 'Volby článku',
    5 => '',
    6 => 'Subscribe to \'%s\''
);

###############################################################################
# submit.php

$LANG12 = array(
    1 => 'Pro tento %s musíte být přihlášen jako uživatel.',
    2 => 'Přihlásit',
    3 => 'Nový uživatel',
    4 => '',
    5 => '',
    6 => 'Publikovat článek',
    7 => 'Vyžadováno přihlášení',
    8 => 'Publikování',
    9 => 'Pro publikování na těchto stránkách následujte prosím tato prostá doporučení: <ul><li>Vyplňte všechna povinná pole<li>Zadávejte kompletní a přesné informace<li>Dvakrát si zkontrolujte URL</ul>',
    10 => 'Titulek',
    11 => '',
    12 => 'Datum začátku',
    13 => 'Datum konce&nbsp;&nbsp;&nbsp;',
    14 => 'Umístění',
    15 => 'Popis',
    16 => '',
    17 => '',
    18 => '',
    19 => 'Přečtěte si',
    20 => '',
    21 => '',
    22 => 'Chyba: nevyplněná pole',
    23 => 'Prosím vyplňte všechna pole. Vše je povinné.',
    24 => 'Publikace provedena',
    25 => 'Vaše %s publikace byla provedena.',
    26 => 'Omezení rychlosti publikování',
    27 => 'Uživatel',
    28 => 'Sekce',
    29 => 'Článek',
    30 => 'Poslední publikace byla před ',
    31 => " sekundami.  Tato stránka vyžaduje {$_CONF['speedlimit']} sekund mezi publikacemi",
    32 => 'Náhled',
    33 => 'Náhled článku',
    34 => 'Odhlásit',
    35 => 'HTML tagy nejsou podporovány',
    36 => 'Typ publikace',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Adresa 1',
    45 => 'Adresa 2',
    46 => 'Město',
    47 => 'Země',
    48 => 'Směrové číslo',
    49 => '',
    50 => '',
    51 => 'Umístění',
    52 => 'Smazat',
    53 => 'Vytvořit účet',
    54 => 'Story Introduction',
    55 => 'Story Body'
);

###############################################################################
# ADMIN PHRASES - These are file phrases used in admin scripts
###############################################################################

###############################################################################
# admin/auth.inc.php

$LANG20 = array(
    1 => 'Autentikace vyžadována',
    2 => 'Přístup odepřen! Nesprávné přihlašovací údaje',
    3 => 'Neplatné heslo pro uživatele',
    4 => 'Uživatel:',
    5 => 'Heslo:',
    6 => 'Každý přístup do administrátorské části stránek je zapisován do log_file a je tam také kontrolován.<br' . XHTML . '>Tato stránka je jen pro autorizované uživatele s administrátorskými právy.',
    7 => 'Přihlásit'
);

###############################################################################
# admin/block.php

$LANG21 = array(
    1 => 'Nedostatečná administrátorská práva',
    2 => 'Nemáte povolen přístup k této části administrace.',
    3 => 'Editor bloků',
    4 => 'There was a problem reading this feed (see error.log for details).',
    5 => '',
    6 => '',
    7 => 'Vše',
    8 => 'Úroveň práv bloku',
    9 => 'Pořadí bloku',
    10 => '',
    11 => 'Blok Portálu',
    12 => 'Normální blok',
    13 => 'Volby Bloku Portálu',
    14 => 'RDF URL',
    15 => 'Last RDF Update',
    16 => 'Volby bloku',
    17 => 'Obsah bloku',
    18 => 'Prosím vyplňte Titulek bloku, Úroveň práv a Obsah',
    19 => 'Manažer bloků',
    20 => '',
    21 => 'Úroveň práv bloku',
    22 => '',
    23 => 'Pořadí bloku',
    24 => '',
    25 => 'Pro smazání a editaci bloku, klepněte na blok níže.  Pro vytvoření nového bloku klepněte na Nový blok výše.',
    26 => 'Vzhled bloku',
    27 => 'PHP Blok',
    28 => 'Volby PHP Bloku',
    29 => 'Funkce bloku',
    30 => 'If you would like to have one of your blocks use PHP code, enter the name of the function above.  Your function name must start with the prefix "phpblock_" (e.g. phpblock_getweather).  If it does not have this prefix, your function will NOT be called.  We do this to keep people who may have hacked your Geeklog installation from putting arbitrary function calls that may be harmful to your system.  Be sure not to put empty parenthisis "()" after your function name.  Finally, it is recommended that you put all your PHP Block code in /path/to/geeklog/system/lib-custom.php.  That will allow the code to stay with you even when you upgrade to a newer version of Geeklog.',
    31 => 'Chyba v PHP Bloku.  Funkce, %s, neexistuje.',
    32 => 'Chyba - neexistující pole',
    33 => 'You must enter the URL to the .rdf file for portal blocks',
    34 => 'You must enter the title and the function for PHP blocks',
    35 => 'You must enter the title and the content for normal blocks',
    36 => 'You must enter the content for layout blocks',
    37 => 'Špatné jméno funkce PHP bloku',
    38 => 'Functions for PHP Bloky must have the prefix \'phpblock_\' (e.g. phpblock_getweather).  The \'phpblock_\' prefix is required for security reasons to prevent the execution of arbitrary code.',
    39 => 'Strana',
    40 => 'Vlevo',
    41 => 'Vpravo',
    42 => 'You must enter the blockorder and security level for Geeklog default blocks',
    43 => 'Jen na Homepage',
    44 => '',
    45 => "You are trying to access a block that you don't have rights to.  This attempt has been logged. Please <a href=\"{$_CONF['site_admin_url']}/block.php\">go back to the block administration screen</a>.",
    46 => 'Nový blok',
    47 => '',
    48 => 'Jméno bloku',
    49 => ' (bez mezer, musí být unikátní)',
    50 => 'The Block Name can not be empty',
    51 => 'včetně http://',
    52 => 'Pokud necháte prázdné - ikona helpu se nebude zobrazovat.',
    53 => 'Povolit',
    54 => 'uložit',
    55 => 'zrušit akci',
    56 => 'smazat',
    57 => 'Move Block Down',
    58 => 'Move Block Up',
    59 => 'Move block to the right side',
    60 => 'Move block to the left side',
    61 => 'No Title',
    62 => 'Article Limit',
    63 => 'Bad Block Title',
    64 => 'Your Title must not be empty and cannot contain HTML!',
    65 => 'Order',
    66 => 'Autotags',
    67 => 'Check to allow autotags',
    68 => 'The feed for this portal block is too long to display. Please set a maximum number of articles to import for the block in the block setup screen, or a global maximum in Geeklog Configuration.'
);

###############################################################################
# admin/story.php

$LANG24 = array(
    1 => 'Předešlé články',
    2 => 'Další články',
    3 => 'Režim',
    4 => 'Publikační režim',
    5 => 'Editor článků',
    6 => 'Nejsou zde články',
    7 => 'Autor',
    8 => 'uložit',
    9 => 'náhled',
    10 => 'zrušit akci',
    11 => 'smazat',
    12 => 'ID',
    13 => '',
    14 => '',
    15 => 'Datum publikace',
    16 => 'Intro Text',
    17 => 'Text',
    18 => 'Zhlédnuto',
    19 => 'Komentáře',
    20 => 'Ping',
    21 => 'Send Ping',
    22 => 'Seznam článků',
    23 => 'Pro editaci nebo smazání článku klepněte na jeho číslo níže. Pro zobrazení,klepněte na titulek článku, který chcete vidět. Pro vytvoření nového článku klepněte na Nový článek výše.',
    24 => 'The ID you chose for this story is already in use. Please use another ID.',
    25 => 'Error when saving story',
    26 => 'Náhled',
    27 => 'If you use [unscaledX] instead of [imageX], the image will be inserted at its original dimensions.',
    28 => '<p><b>PREVIEWING</b>: Previewing a story with images attached is best done by saving the article as a draft INSTEAD OF hitting the preview button.  Use the preview button only when images are not attached.',
    29 => 'Trackbacks',
    30 => 'File Upload Errors',
    31 => 'Prosím vyplnťe Autor, Titulek a Intro Text',
    32 => 'Zvýraznit',
    33 => 'V sytému může být jen jeden zvýrazněný článek (ten se bude zobrazovat vždy jako první)',
    34 => 'Verze pro tiskárnu',
    35 => 'Ano',
    36 => 'Ne',
    37 => 'Více od',
    38 => 'Více z',
    39 => 'Posláno emailem',
    40 => '',
    41 => "Pokoušíte se editovat odkaz na nějž nemáte dostatečná práva.  Tento pokus byl zaznamenán.  Můžete si jen prohlédnout články níže. Prosím <a href=\"{$_CONF['site_admin_url']}/story.php\">vraťte se na administraci článků</a> když skončíte.",
    42 => "Pokoušíte se editovat odkaz na nějž nemáte dostatečná práva.  Tento pokus byl zaznamenán.  Prosím <a href=\"{$_CONF['site_admin_url']}/story.php\">vraťte se na administraci článků</a>.",
    43 => '',
    44 => '',
    45 => '',
    46 => '<b>PAMATUJTE:</b> pokud zadáte datum v budoucnosti, tento článek nebude publikován do tohoto data.  To znamená, že článek nebude vidět ani nebude zahrnut do vyhledávání a do statistiky stránek před tímto datem.',
    47 => 'Upload obrázků',
    48 => 'obrázek',
    49 => 'vpravo',
    50 => 'vlevo',
    51 => 'k přidání obrázků (max. velikost 200x200px) do článku musíte vložit speciálně formátovaný text.<br' . XHTML . '>Tento text vypadá takto: [imageX](systém umístí sám), [imageX_right](systém umístí vpravo od textu) nebo [imageX_left](systém umístí vlevo od textu) - kde X je číslo obrázku jež je přidáván.<br' . XHTML . '>PAMATUJTE: musíte použít obrázky jež jsou přidávány.  V opačném případě nebude možno publikovat článek.<BR><P><B>NÁHLED</B>: Pro náhled článku s obrázky je nejlépe použít náhled Verze pro tiskárnu.  Tlačítko <i>náhled</i> prosím používejte jen pro prohlížení článků bez obrázků.',
    52 => '',
    53 => ' nepoužito.  Před uložením změn musíte vložit obrázek do Intro textu nebo textu.',
    54 => 'Přidaný obrázek nepoužit',
    55 => 'Následující chyby se vyskytly při publikaci vašeho článku.  Prosím opravte tyto chyby před konečnou publikací.',
    56 => 'Ikona Sekce.',
    57 => 'View unscaled image',
    58 => 'Story Management',
    59 => 'Option',
    60 => '',
    61 => 'Auto Archive',
    62 => 'Auto Delete',
    63 => 'Disable Comments',
    64 => '',
    65 => '',
    66 => '',
    67 => 'Expand the Content Edit Area size',
    68 => 'Reduce the Content Edit Area size',
    69 => 'Publish Story Date',
    70 => 'Toolbar Selection',
    71 => 'Basic Toolbar',
    72 => 'Common Toolbar',
    73 => 'Advanced Toolbar',
    74 => 'Advanced II Toolbar',
    75 => 'Full Featured',
    76 => 'Publish Options',
    77 => 'Javascript needs to be enabled for Advanced Editor. Option can be disabled in the main site config.php',
    78 => 'Click <a href="%s/story.php?mode=edit&amp;sid=%s&amp;editopt=default">here</a> to use default editor',
    79 => 'Preview',
    80 => 'Editor',
    81 => 'Publish Options',
    82 => 'Images',
    83 => 'Archive Options',
    84 => 'Permissions',
    85 => 'Show All',
    86 => 'Advanced Editor',
    87 => 'Story Stats',
    88 => 'Wiki-style format',
    89 => 'Meta Description',
    90 => 'Meta Keywords',
    91 => 'You can always hit "Preview" to extend the expiry time.'
);

###############################################################################
# admin/topic.php

$LANG27 = array(
    1 => 'Editor sekcí',
    2 => 'ID sekce',
    3 => 'Jméno sekce',
    4 => 'Ikona sekce',
    5 => '(bez mezer)',
    6 => 'Smazání sekce způsobí smazání článků a komentářů k nim i její ikony!',
    7 => 'Prosím vyplňte ID sekce a Jméno sekce',
    8 => 'Manažer sekcí',
    9 => 'Pro úpravu a smazání sekce klepněte na její jméno níže.  Pro vytvoření nové sekce klepněte na Nová sekce výše.',
    10 => 'pořadí',
    11 => 'článků/stránku',
    12 => 'Přístup odepřen',
    13 => "Pokoušíte se editovat sekci na níž nemáte dostatečná práva.  Tento pokus byl zaznamenán. Prosím <a href=\"{$_CONF['site_admin_url']}/topic.php\">vraťte se na administraci sekcí</a>.",
    14 => 'typ řazení',
    15 => 'abecedně',
    16 => 'nastaveno',
    17 => 'Nová sekce',
    18 => 'Administrace',
    19 => 'uložit',
    20 => 'zrušit akci',
    21 => 'smazat',
    22 => 'Default',
    23 => 'make this the default topic for new story submissions',
    24 => '(*)',
    25 => 'Archive Topic',
    26 => 'make this the default topic for archived stories. Only one topic allowed.',
    27 => 'Or Upload Topic Icon',
    28 => 'Maximum',
    29 => 'File Upload Errors',
    30 => 'Stories in Topic'
);

###############################################################################
# admin/user.php

$LANG28 = array(
    1 => 'Editor uživatelů',
    2 => 'ID uživatele',
    3 => 'Uživatel',
    4 => 'Jméno uživatele',
    5 => 'Heslo',
    6 => 'Úroveň práv',
    7 => 'Emailová adresa',
    8 => 'Homepage',
    9 => '(bez mezer)',
    10 => 'Please fill in the Uživatel, Full name, Security Level and Email Address fields',
    11 => 'Manažer uživatelů',
    12 => 'To modify or smazat a user, click on that user below.  To create a new user click the new user button to the left. You can do simple searches by entering parts of a Uživatel,email address or fullname (e.g.*son* or *.edu) in the form below.',
    13 => 'Úroveň práv',
    14 => 'Datum registrace',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => 'uložit',
    21 => 'Uživatel již existuje.',
    22 => 'Chyba',
    23 => 'Hromadné přidání',
    24 => 'Hromadné přidání uživatelů',
    25 => 'You can import a batch of users into Geeklog.  The import file must a tab-delimited text file and must have the fields in the following order: full name, Uživatel, email address.  Each user you import will be emailed with a random Heslo.  You must have one user entered per line.  Failure to follow these instructions will cause problems that may require manual work so double check your entries!',
    26 => '',
    27 => '',
    28 => 'Zaškrtnout pro smazání obrázku',
    29 => 'Cesta',
    30 => 'Import',
    31 => 'Noví uživatelé',
    32 => 'HOTOVO. Importováno %d a vyskytlo se %d chyb.',
    33 => 'Potvrdit',
    34 => 'Chyba: Specifikujte soubor.',
    35 => 'Last Login',
    36 => '(never)',
    37 => 'UID',
    38 => 'Group Listing',
    39 => 'Password (again)',
    40 => 'Registration Date',
    41 => 'Last login Date',
    42 => 'Banned',
    43 => 'Awaiting Activation',
    44 => 'Awaiting Authorization',
    45 => 'Active',
    46 => 'User Status',
    47 => 'Edit',
    48 => 'Show Admin Groups',
    49 => 'Admin Group',
    50 => 'Check to allow filtering this group as an Admin Use Group',
    51 => 'Online Days',
    52 => '<br' . XHTML . '>Note: "Online Days" is the number of days between the first registration and the last login.',
    53 => 'registered',
    54 => 'Batch Delete',
    55 => 'This only works if you have <code>$_CONF[\'lastlogin\'] = true;</code> in your config.php',
    56 => 'Please choose the type of user you want to delete and press "Update List". Then, uncheck those from the list you do not want to delete and press "Delete". Please note that you will only delete those that are currently visible in case the list spans over several pages.',
    57 => 'Phantom users',
    58 => 'Short-Time Users',
    59 => 'Old Users',
    60 => 'Users that registered more than ',
    61 => ' months ago, but never logged in.',
    62 => 'Users that registered more than ',
    63 => ' months ago, then logged in within 24 hours, but since then never came back to your site.',
    64 => 'Normal users, who simply did not visit your site since ',
    65 => ' months.',
    66 => 'Update List',
    67 => 'Months since registration',
    68 => 'Online Hours',
    69 => 'Offline Months',
    70 => 'could not be deleted',
    71 => 'sucessfully deleted',
    72 => 'No User selected for deletion',
    73 => 'Are You sure you want to permanently delete ALL selected users?',
    74 => 'Recent Users',
    75 => 'Users that registered in the last ',
    76 => ' months',
    77 => 'Email site login reminder to selected users',
    78 => 'Send Reminder',
    79 => 'No User selected for reminders',
    80 => 'Successfully sent Reminders',
    81 => 'Reminder to verify account for %s',
    82 => "Your account on {$_CONF['site_name']} has not been accesssed since %s and will be disabled if not accessed in the 30 days.",
    83 => "Your account on {$_CONF['site_name']} has not been used since it was created and will deleted soon if not accessed.",
    84 => "Your login name is: %s  for our site: {$_CONF['site_url']}",
    85 => 'If you have forgotten the password use the following link: %s',
    86 => 'Include',
    87 => 'Reminders',
    88 => 'Default Group',
    89 => 'Check to make this a default group for new users',
    90 => 'Apply "Default Group" change to existing user accounts'
);

###############################################################################
# admin/moderation.php

$LANG29 = array(
    1 => 'Potvrdit',
    2 => 'Smazat',
    3 => 'Editovat',
    4 => 'Profil',
    10 => 'Titulek',
    11 => 'Datum začátku',
    12 => 'URL',
    13 => 'Kategorie',
    14 => 'Datum',
    15 => 'Sekce',
    16 => 'Jméno uživatele',
    17 => 'Celé jméno uživatele',
    18 => 'Email',
    34 => 'Administrace weblogu',
    35 => 'Přidání článku',
    36 => 'Parent or Comment',
    37 => '',
    38 => 'Přidat',
    39 => 'Nyní zde není nic k moderování',
    40 => 'Publikace uživatele',
    41 => 'Comment Submissions',
    42 => 'Username',
    43 => 'Auto-publish Comments?'
);

###############################################################################
# admin/mail.php

$LANG31 = array(
    1 => "{$_CONF['site_name']} - zasílání emailů",
    2 => 'Od',
    3 => 'Zpětná  adresa',
    4 => 'Hlavička',
    5 => 'Zpráva',
    6 => 'Poslat:',
    7 => 'Všem uživatelům',
    8 => 'Admin',
    9 => 'Možnosti',
    10 => 'HTML',
    11 => 'Urgentní zpráva!',
    12 => 'Poslat',
    13 => 'Smazat',
    14 => 'Ignorovat uživ. nastavení',
    15 => 'Chyba při zasílání: ',
    16 => 'Zasláno: ',
    17 => "<a href={$_CONF['site_admin_url']}/mail.php>Poslat další zprávu</a>",
    18 => 'Pro',
    19 => 'POZOR: chcete-li zaslat zprávu všem uživatelům, vyberte Logged-in Users skupinu z roletové nabídky.',
    20 => "Odesláno <successcount> zpráv a nezasláno <failcount> zpráv.  Detaily jsou níže u každého pokusu o zaslání zvlášť.  Můžete se pokusit znovu <a href=\"{$_CONF['site_admin_url']}/mail.php\">zaslat zprávu</a> nebo <a href=\"{$_CONF['site_admin_url']}/moderation.php\">se vrátit na stránku administrace</a>.",
    21 => 'Chyby',
    22 => 'Úspěšně',
    23 => 'Bez chyb',
    24 => 'Neúspěšně',
    25 => '- Vybrat skupinu -',
    26 => 'Prosím vyplňte všechna pole ve formuláři a vyberte skupinu uživatelů z roletové nabídky.'
);

###############################################################################
# admin/plugins.php

$LANG32 = array(
    1 => 'Installing plugins could possibly cause damage to your Geeklog installation and, possibly, to your system.  It is important that you only install plugins downloaded from the <a href="http://www.geeklog.net" target="_blank">Geeklog Homepage</a> as we thoroughly test all plugins submitted to our site on a variety of operating systems.  It is important that you understand that the plugin installation process will require the execution of a few filesystem commands which could lead to security problems particularly if you use plugins from third party sites.  Even with this warning you are getting, we do not gaurantee the success of any installation nor are we liable for damage caused by installing a Geeklog plugin.  In other words, install at your own risk.  For the wary, directions on how to manually install a plugin is included with each plugin package.',
    2 => 'Plug-in Installation Disclaimer',
    3 => 'Plug-in Installation Form',
    4 => 'Plug-in File',
    5 => 'Plug-in List',
    6 => 'Warning: Plug-in Already Installed!',
    7 => 'The plug-in you are trying to install already exists.  Please delete the plugin before re-installing it',
    8 => 'Plugin Compatibility Check Failed',
    9 => 'This plugin requires a newer version of Geeklog. Either upgrade your copy of <a href="http://www.geeklog.net">Geeklog</a> or get a newer version of the plug-in.',
    10 => '<br' . XHTML . '><b>There are no plugins currently installed.</b><br' . XHTML . '><br' . XHTML . '>',
    11 => 'To modify or delete a plug-in, click on that plug-in\'s number below. To learn more about a plug-in, click the plug-in name and you will be directed to that plug-in\'s website. To install or upgrade a plug-in please consult it\'s documentation.',
    12 => 'no plugin name provided to plugineditor()',
    13 => 'Plugin Editor',
    14 => 'New Plug-in',
    15 => 'Administrace',
    16 => 'Plug-in Name',
    17 => 'Plug-in Version',
    18 => 'Geeklog Version',
    19 => 'Enabled',
    20 => 'Yes',
    21 => 'No',
    22 => 'Install',
    23 => 'uložit',
    24 => 'zrušit akci',
    25 => 'smazat',
    26 => 'Plug-in Name',
    27 => 'Plug-in Homepage',
    28 => 'Plug-in Version',
    29 => 'Geeklog Version',
    30 => 'smazat Plug-in?',
    31 => 'Are you sure you want to delete this plug-in?  By doing so you will remove all the data and data structures that this plug-in uses.  If you are sure, click delete again on the form below.',
    32 => '<p><b>Error AutoLink tag not correct format</b></p>',
    33 => 'Code Version',
    34 => 'Update',
    35 => 'Edit',
    36 => 'Code',
    37 => 'Data',
    38 => 'Update!',
    39 => 'Upload a plugin',
    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
    41 => 'Upload',
    42 => 'Click to update',
    99 => 'An unknown error occured',
    100 => 'Ok.',
    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
    103 => 'The uploaded file was only partially uploaded.',
    104 => 'No file was uploaded.',
    105 => '(undefined error)',
    106 => 'Missing a temporary folder.',
    107 => 'Failed to write file to disk.',
    108 => 'File upload stopped by extension.'
);

###############################################################################
# admin/syndication.php

$LANG33 = array(
    1 => 'create feed',
    2 => 'save',
    3 => 'delete',
    4 => 'cancel',
    10 => 'Content Syndication',
    11 => 'New Feed',
    12 => 'Admin Home',
    13 => 'To modify or delete a feed, click on the feed\'s title below. To create a new feed, click on New Feed above.',
    14 => 'Title',
    15 => 'Type',
    16 => 'Filename',
    17 => 'Format',
    18 => 'last updated',
    19 => 'Enabled',
    20 => 'Yes',
    21 => 'No',
    22 => '<i>(no feeds)</i>',
    23 => 'all Stories',
    24 => 'Feed Editor',
    25 => 'Feed Title',
    26 => 'Limit',
    27 => 'Length of entries',
    28 => '(0 = no text, 1 = full text, other = limit to that number of chars.)',
    29 => 'Description',
    30 => 'Last Update',
    31 => 'Character Set',
    32 => 'Language',
    33 => 'Contents',
    34 => 'Entries',
    35 => 'Hours',
    36 => 'Select type of feed',
    37 => '',
    38 => 'Error: Missing Fields',
    39 => 'Please fill in the Feed Title, Description, and Filename.',
    40 => 'Please enter a  number of entries or number of hours.',
    41 => 'Links',
    42 => '',
    43 => 'All',
    44 => 'None',
    45 => 'Header-link in topic',
    46 => 'Limit Results',
    47 => 'Search',
    48 => 'Edit',
    49 => 'Feed Logo',
    50 => "Relative to site url ({$_CONF['site_url']})",
    51 => 'The filename you have chosen is already used by another feed. Please choose a different one.',
    52 => 'Error: existing Filename',
    53 => 'All Frontpage Stories',
    54 => 'Please select the type of feed to create.',
    55 => 'Articles'
);

###############################################################################
# confirmation and error messages

$MESSAGE = array(
    1 => "Vaše přihlašovací heslo Vám bylo zasláno na zadanou adresu. Prosím následujte prosté instrukce v poště. Děkujeme Vám za účast na {$_CONF['site_name']}",
    2 => "Děkujeme za přidání článku na {$_CONF['site_name']}..",
    3 => '',
    4 => '',
    5 => 'Vaše informace o účtu byly uloženy.',
    6 => 'Vaše vlastní nastavení bylo uloženo.',
    7 => 'Vaše nastavení komentářů bylo uloženo.',
    8 => 'Byl jste úspěšně odhlášen.',
    9 => 'Článek byl uložen.',
    10 => 'Článek byl vymazán.',
    11 => 'Bloky byly uloženy.',
    12 => 'Blok byl odstraněn.',
    13 => 'Sekce byla uložena.',
    14 => 'Sekce a články s komentáři v ní byla smazána.',
    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => 'Uživatel byl přidán/změněn.',
    22 => 'Uživatel byl odstraněn.',
    23 => '',
    24 => '',
    25 => '',
    26 => '',
    27 => 'Vzkaz poslán.',
    28 => 'The plug-in has been successfully saved',
    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
    30 => 'Přístup odepřen',
    31 => '',
    32 => '',
    33 => '',
    34 => '',
    35 => '',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => 'Systémové zprávy',
    41 => '',
    42 => '',
    43 => '',
    44 => 'The plug-in was successfully installed!',
    45 => 'The plug-in was successfully deleted.',
    46 => '',
    47 => '',
    48 => "Děkujeme za registraci na {$_CONF['site_name']}.  Vaše heslo pro přístup do systému Vám bylo zasláno na email, který jste zadali.",
    49 => 'Skupina byla úspěšně uložena.',
    50 => 'Skupina byla úspěšně smazána.',
    51 => 'This username is already in use. Please choose another one.',
    52 => 'The email address provided does not appear to be a valid email address.',
    53 => 'Your new password has been accepted. Please use your new password below to log in now.',
    54 => 'Your request for a new password has expired. Please try again below.',
    55 => 'An email has been sent to you and should arrive momentarily. Please follow the directions in the message to set a new password for your account.',
    56 => 'The email address provided is already in use for another account.',
    57 => 'Your account has been successfully deleted.',
    58 => 'Your feed has been successfully saved.',
    59 => 'The feed has been successfully deleted.',
    60 => 'The plugin was successfully updated',
    61 => 'Plugin %s: Unknown message placeholder',
    62 => 'The trackback comment has been deleted.',
    63 => 'An error occurred when deleting the trackback comment.',
    64 => 'Your trackback comment has been successfully sent.',
    65 => 'Weblog directory service successfully saved.',
    66 => 'The weblog directory service has been deleted.',
    67 => 'The new password does not match the confirmation password!',
    68 => 'You have to enter the correct current password.',
    69 => 'Your account has been blocked!',
    70 => 'Your account is awaiting administrator approval.',
    71 => 'Your account has now been confirmed and is awaiting administrator approval.',
    72 => 'An error occured while attempting to install the plugin. See error.log for details.',
    73 => 'An error occured while attempting to uninstall the plugin. See error.log for details.',
    74 => 'The pingback has been successfully sent.',
    75 => 'Trackbacks must be sent using a POST request.',
    76 => 'Do you really want to delete this item?',
    77 => 'WARNING:<br' . XHTML . '>You have set your default encoding to UTF-8. However, your server does not support multibyte encodings. Please install mbstring functions for PHP or choose a different character set/language.',
    78 => 'Please make sure that the email address and the confirmation email address are the same.',
    79 => 'The page you have been trying to open refers to a function that no longer exists on this site.',
    80 => 'The plugin that created this feed is currently disabled. You will not be able to edit this feed until you re-enable the parent plugin.',
    81 => 'You may have mistyped your login credentials.  Please try logging in again below.',
    82 => 'You have exceeded the number of allowed login attempts.  Please try again later.',
    83 => 'To change your password, email address, or for how long to remember you, please enter your current password.',
    84 => 'To delete your account, please enter your current password.',
    85 => 'There was a problem sending the email.',
    86 => 'The OpenID server invalidated your login attempt.',
    87 => 'OpenID login operation cancelled by user.',
    88 => 'The OpenID server returned an error.',
    89 => 'Unable to find an OpenID server for the given identity URL.',
    90 => 'OpenID identification cancelled.',
    91 => 'You specified an invalid identity URL.',
    92 => "Please <a href=\"{$_CONF['site_admin_url']}/sectest.php\">check the security of your site</a> before using it!",
    93 => 'Database back up was successful.',
    94 => 'Backup Failed: Filesize less than 1kb',
    95 => 'There was an error.',
    96 => '',
    97 => '',
    98 => 'The plugin was successfully uploaded.',
    99 => 'The plugin already exists.',
    100 => 'The plugin file you uploaded was not a GZip or Zip compressed archive.',
    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
    400 => 'Not all required fields have been passed validation',
    401 => 'Please enter Fullname'
);

###############################################################################

$LANG_ACCESS = array(
    'access' => 'Práva',
    'ownerroot' => 'Vlastník-Root',
    'group' => 'Skupina',
    'readonly' => 'Jen pro čtení',
    'accessrights' => 'Přístupová práva',
    'owner' => 'Vlastník',
    'grantgrouplabel' => 'Zaručuje práva vyšší než práva skupiny pro editaci',
    'permmsg' => 'PAMATUJTE: <i>uživatelé</i> jsou přihlášení uživatelé weblogu a <i>hosté</i> jsou všichni, kdo si prohlížejí weblog bez přihlášení.',
    'securitygroups' => 'Skupiny/Úroveň práv',
    'editrootmsg' => "Even though you are a User Administrator, you can't edit a root user without first being a root user yourself.  You can edit all other users except root users. Please note that all attempts to illegally edit root users are logged.  Please go back to the <a href=\"{$_CONF['site_admin_url']}/user.php\">User Administration page</a>.",
    'securitygroupsmsg' => 'Select the checkboxes for the groups you want the user to belong to.',
    'groupeditor' => 'Editor skupin uživatelů',
    'description' => 'Popis',
    'name' => 'Jméno',
    'rights' => 'Práva',
    'missingfields' => 'Chybějící pole',
    'missingfieldsmsg' => 'You must supply the name and a description for a group',
    'groupmanager' => 'Manažer skupin uživatelů',
    'newgroupmsg' => 'To modify or delete a group, click on that group below. To create a new group click new group above. Please note that core groups cannot be deleted because they are used v systému.',
    'groupname' => 'Jméno skupiny uživatelů',
    'coregroup' => 'Hlavní skupina',
    'yes' => 'Ano',
    'no' => 'Ne',
    'corerightsdescr' => "This group is a core {$_CONF['site_name']} Group.  Therefore the rights for this group cannot be edited.  Below is a read-only list of the rights this group has access to.",
    'groupmsg' => 'Security Groups on this site are hierarchical.  By adding this group to any of the groups below you will giving this group the same rights that those groups have.  Where possible it is encouraged you use the groups below to give rights to a group.  If you need this group to have custom rights then you can select the rights to various site features in the section below called \'Rights\'.  To add this group to any of the ones below simply check the box next to the group(s) that you want.',
    'coregroupmsg' => "This group is a core {$_CONF['site_name']} Group.  Therefore the groups that this group belongs to cannot be edited.  Below is a read-only list of the groups this group belongs to.",
    'rightsdescr' => 'A groups access to a certain right below can be given directly to the group OR to a different group that this group is a part of.  The ones you see below without a checkbox are the rights that have been given to this group because it belongs to another group with that right.  The rights with checkboxes below are rights that can be given directly to this group.',
    'lock' => 'Uzamčeno',
    'members' => 'Uživatelé',
    'anonymous' => 'Hosté',
    'permissions' => 'Přidělení oprávnění',
    'permissionskey' => 'R = čtení, E = editace, editační práva v sobě zahrnují i právo číst!',
    'edit' => 'Editace',
    'none' => 'Není',
    'accessdenied' => 'Přístup odepřen',
    'storydenialmsg' => "You do not have access to view this story.  This could be because you aren't a member of {$_CONF['site_name']}.  Please <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"> become a member</a> of {$_CONF['site_name']} to receive full membership access!",
    'nogroupsforcoregroup' => 'This group doesn\'t belong to any of the other groups',
    'grouphasnorights' => 'This group doesn\'t have access to any of the administrative features of this site',
    'newgroup' => 'Nová skupina uživatelů',
    'adminhome' => 'Administrace',
    'save' => 'uložit',
    'cancel' => 'zrušit akci',
    'delete' => 'smazat',
    'canteditroot' => 'You have tried to edit the Root group but you are not in the Root group yourself therefore your access to this group is denied.  Please contact the system administrator if you feel this is Chyba',
    'listusers' => 'List Users',
    'listthem' => 'list',
    'usersingroup' => 'Users in group "%s"',
    'usergroupadmin' => 'User Group Administration',
    'add' => 'Add',
    'remove' => 'Remove',
    'availmembers' => 'Available Members',
    'groupmembers' => 'Group Members',
    'canteditgroup' => 'To edit this group, you have to be a member of the group. Please contact the system administrator if you feel this is an error.',
    'cantlistgroup' => 'To see the members of this group, you have to be a member yourself. Please contact the system administrator if you feel this is an error.',
    'editgroupmsg' => 'To modify the group membership, click on the member names(s) and use the add or remove buttons. If the member is a member of the group, their name will appear on the right side only. Once you are complete - press <b>Save</b> to update the group and return to the main group admin page.',
    'listgroupmsg' => 'Listing of all current members in the group: <b>%s</b>',
    'search' => 'Search',
    'submit' => 'Submit',
    'limitresults' => 'Limit Results',
    'group_id' => 'Group ID',
    'plugin_access_denied_msg' => 'You are illegally trying access a plugin administration page.  Please note that all attempts to illegally access this page are logged.',
    'groupexists' => 'Group name already exists',
    'groupexistsmsg' => 'There is already a group with this name. Group names must be unique.'
);

###############################################################################
# admin/database.php

$LANG_DB_BACKUP = array(
    'last_ten_backups' => 'Last 10 Back-ups',
    'do_backup' => 'Do Backup',
    'backup_successful' => 'Database back up was successful.',
    'db_explanation' => 'To create a new backup of your Geeklog system, hit the button below',
    'not_found' => "Incorrect path or mysqldump utility not executable.<br" . XHTML . ">Check <strong>\$_DB_mysqldump_path</strong> definition in config.php.<br" . XHTML . ">Variable currently defined as: <var>{$_DB_mysqldump_path}</var>",
    'zero_size' => 'Backup Failed: Filesize was 0 bytes',
    'path_not_found' => "{$_CONF['backup_path']} does not exist or is not a directory",
    'no_access' => "Chyba: Directory {$_CONF['backup_path']} is not accessible.",
    'backup_file' => 'Backup file',
    'size' => 'Size',
    'bytes' => 'Bytes',
    'total_number' => 'Total number of backups: %d',
    'download' => 'Click to download this file',
    'new_backup' => 'New Backup',
    'delete_failure' => 'One or more backup files could not be deleted.',
    'delete_success' => 'Backup file(s) successfully deleted.',
    'convert_menu' => 'Convert to InnoDB',
    'convert_title' => 'Convert to InnoDB tables',
    'convert_button' => 'Convert',
    'sorry_no_innodb' => 'Sorry, your version of MySQL does not support InnoDB tables.',
    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
    'innodb_success' => 'Successfully converted tables to InnoDB.',
    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
    'optimize_menu' => 'Optimize Tables',
    'optimize_title' => 'Optimize Tables',
    'optimize_button' => 'Optimize',
    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
    'last_optimization' => 'Last optimization',
    'optimization_patience' => 'Note: Optimization may take some time - please be patient.',
    'optimize_success' => 'Successfully optimized database tables.'
);

###############################################################################

$LANG_BUTTONS = array(
    1 => 'Homepage',
    2 => 'Kontakt',
    3 => 'Publikovat',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Statistika',
    8 => 'Vlastní nastavení',
    9 => 'Hledání',
    10 => 'rozšířené hledání',
    11 => 'Directory'
);

###############################################################################
# 404.php

$LANG_404 = array(
    1 => '404 Error',
    2 => 'Gee, I\'ve looked everywhere but I can not find <b>%s</b>.',
    3 => "<p>We're sorry, but the file you have requested does not exist. Please feel free to check the <a href=\"{$_CONF['site_url']}\">main page</a> or the <a href=\"{$_CONF['site_url']}/search.php\">search page</a> to see if you can find what you lost."
);

###############################################################################
# login form

$LANG_LOGIN = array(
    1 => 'Je nutné se přihlásit',
    2 => 'Promiňte, pro přístup je nutné být přihlášen jako uživatel.',
    3 => 'Přihlásit',
    4 => 'Nový uživatel'
);

###############################################################################
# trackback.php

$LANG_TRB = array(
    'trackback' => 'Trackback',
    'from' => 'from',
    'tracked_on' => 'Tracked on',
    'read_more' => '[read more]',
    'intro_text' => 'Here\'s what others have to say about \'%s\':',
    'no_comments' => 'No trackback comments for this entry.',
    'this_trackback_url' => 'Trackback URL for this entry:',
    'num_comments' => '%d trackback comments',
    'send_trackback' => 'Send Pings',
    'preview' => 'Preview',
    'editor_title' => 'Send trackback comment',
    'trackback_url' => 'Trackback URL',
    'entry_url' => 'Entry URL',
    'entry_title' => 'Entry Title',
    'blog_name' => 'Site Name',
    'excerpt' => 'Excerpt',
    'truncate_warning' => 'Note: The receiving site may truncate your excerpt',
    'button_send' => 'Send',
    'button_preview' => 'Preview',
    'send_error' => 'Error',
    'send_error_details' => 'Error when sending trackback comment:',
    'url_missing' => 'No Entry URL',
    'url_required' => 'Please enter at least a URL for the entry.',
    'target_missing' => 'No Trackback URL',
    'target_required' => 'Please enter a trackback URL',
    'error_socket' => 'Could not open socket.',
    'error_response' => 'Response not understood.',
    'error_unspecified' => 'Unspecified error.',
    'select_url' => 'Select Trackback URL',
    'not_found' => 'Trackback URL not found',
    'autodetect_failed' => 'Geeklog could not detect the Trackback URL for the post you want to send your comment to. Please enter it manually below.',
    'trackback_explain' => 'From the links below, please select the URL you want to send your Trackback comment to. Geeklog will then try to determine the correct Trackback URL for that post. Or you can <a href="%s">enter it manually</a> if you know it already.',
    'no_links_trackback' => 'No links found. You can not send a Trackback comment for this entry.',
    'pingback' => 'Pingback',
    'pingback_results' => 'Pingback results',
    'send_pings' => 'Send Pings',
    'send_pings_for' => 'Send Pings for "%s"',
    'no_links_pingback' => 'No links found. No Pingbacks were sent for this entry.',
    'pingback_success' => 'Pingback sent.',
    'no_pingback_url' => 'No pingback URL found.',
    'resend' => 'Resend',
    'ping_all_explain' => 'You can now notify the sites you linked to (<a href="http://en.wikipedia.org/wiki/Pingback">Pingback</a>), advertise that your site has been updated by pinging weblog directory services, or send a <a href="http://en.wikipedia.org/wiki/Trackback">Trackback</a> comment in case you wrote about a post on someone else\'s site.',
    'pingback_button' => 'Send Pingback',
    'pingback_short' => 'Send Pingbacks to all sites linked from this entry.',
    'pingback_disabled' => '(Pingback disabled)',
    'ping_button' => 'Send Ping',
    'ping_short' => 'Ping weblog directory services.',
    'ping_disabled' => '(Ping disabled)',
    'trackback_button' => 'Send Trackback',
    'trackback_short' => 'Send a Trackback comment.',
    'trackback_disabled' => '(Trackback disabled)',
    'may_take_a_while' => 'Please note that sending Pingbacks and Pings may take a while.',
    'ping_results' => 'Ping results',
    'unknown_method' => 'Unknown ping method',
    'ping_success' => 'Ping sent.',
    'error_site_name' => 'Please enter the site\'s name.',
    'error_site_url' => 'Please enter the site\'s URL.',
    'error_ping_url' => 'Please enter a valid Ping URL.',
    'no_services' => 'No weblog directory services configured.',
    'services_headline' => 'Weblog Directory Services',
    'service_explain' => 'To modify or delete a weblog directory service, click on the edit icon of that service below. To add a new weblog directory service, click on "Create New" above.',
    'service' => 'Service',
    'ping_method' => 'Ping method',
    'service_website' => 'Website',
    'service_ping_url' => 'URL to ping',
    'ping_standard' => 'Standard Ping',
    'ping_extended' => 'Extended Ping',
    'ping_unknown' => '(unknown method)',
    'edit_service' => 'Edit Weblog Directory Service',
    'trackbacks' => 'Trackbacks',
    'editor_intro' => 'Prepare your trackback comment for <a href="%s">%s</a>.',
    'editor_intro_none' => 'Prepare your trackback comment.',
    'trackback_note' => 'To send a trackback comment for a story, go to the list of stories and click on "Send Ping" for the story. To send a trackback that is not related to a story, <a href="%s">click here</a>.',
    'pingback_explain' => 'Enter a URL to send the Pingback to. The pingback will point to your site\'s homepage.',
    'pingback_url' => 'Pingback URL',
    'site_url' => 'This site\'s URL',
    'pingback_note' => 'To send a pingback for a story, go to the list of stories and click on "Send Ping" for the story. To send a pingback that is not related to a story, <a href="%s">click here</a>.',
    'pbtarget_missing' => 'No Pingback URL',
    'pbtarget_required' => 'Please enter a pingback URL',
    'pb_error_details' => 'Error when sending the pingback:',
    'delete_trackback' => 'To delete this Trackback click: '
);

###############################################################################
# directory.php

$LANG_DIR = array(
    'title' => 'Article Directory',
    'title_year' => 'Article Directory for %d',
    'title_month_year' => 'Article Directory for %s %d',
    'nav_top' => 'Back to Article Directory',
    'no_articles' => 'No articles.'
);

###############################################################################
# admin/sectest.php

$LANG_SECTEST = array(
    'sectest' => 'Geeklog Security Check',
    'results' => 'Results of the Security Check',
    'okay' => 'Everything seems to be in order.',
    'please_fix' => 'Please fix the above issues before using your site!',
    'please_note' => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
    'public_html' => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
    'installation' => 'installation instructions',
    'directory' => 'directory',
    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
    'fix_it' => 'This is a security risk and should be fixed!',
    'reachable' => 'Your %s is reachable from the web.',
    'not_reachable' => 'Good! Your %s is not reachable from the web.',
    'not_sure' => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
    'remove_inst' => 'You should really remove the install directory %s once you have your site up and running without any errors.',
    'remove_inst2' => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
    'inst_removed' => 'Good! You seem to have removed the install directory already.',
    'fix_password' => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
    'password_okay' => 'Good! You seem to have changed the default account password already.'
);

###############################################################################
# "What's New" Time Strings
# 
# For the first two strings, you can use the following placeholders.
# Order them so it makes sense in your language:
# %i    item, "Stories"
# %n    amount, "2", "20" etc.
# %t    time, "2" (weeks)
# %s    scale, "hrs", "weeks"

$LANG_WHATSNEW = array(
    'new_string' => '%n new %i in the last %t %s',
    'new_last' => 'last %t %s',
    'minutes' => 'minutes',
    'hours' => 'hours',
    'days' => 'days',
    'weeks' => 'weeks',
    'months' => 'months',
    'years' => 'years',
    'minute' => 'minute',
    'hour' => 'hour',
    'day' => 'day',
    'week' => 'week',
    'month' => 'month',
    'year' => 'year'
);

###############################################################################
# Month names

$LANG_MONTH = array(
    1 => 'leden',
    2 => 'únor',
    3 => 'březen',
    4 => 'duben',
    5 => 'květen',
    6 => 'červen',
    7 => 'červenec',
    8 => 'srpen',
    9 => 'září',
    10 => 'říjen',
    11 => 'listopad',
    12 => 'prosinec'
);

###############################################################################
# Weekdays

$LANG_WEEK = array(
    1 => 'neděle',
    2 => 'pondělí',
    3 => 'úterý',
    4 => 'středa',
    5 => 'čtvrtek',
    6 => 'pátek',
    7 => 'sobota'
);

###############################################################################
# Admin - Strings
# 
# These are some standard strings used by core functions as well as plugins to
# display administration lists and edit pages

$LANG_ADMIN = array(
    'search' => 'Search',
    'limit_results' => 'Limit Results',
    'submit' => 'Submit',
    'edit' => 'Edit',
    'edit_adv' => 'Adv. Edit',
    'admin_home' => 'Admin Home',
    'create_new' => 'Create New',
    'create_new_adv' => 'Create New (Adv.)',
    'enabled' => 'Enabled',
    'title' => 'Title',
    'page_title' => 'Page Title',
    'type' => 'Type',
    'topic' => 'Topic',
    'help_url' => 'Help File URL',
    'save' => 'Save',
    'cancel' => 'Cancel',
    'delete' => 'Delete',
    'delete_sel' => 'Delete selected',
    'copy' => 'Copy',
    'no_results' => '- No entries found -',
    'data_error' => 'There was an error processing the subscription data. Please check the data source.',
    'preview' => 'Preview',
    'records_found' => 'Records found',
    'addchild' => 'Add child',
    'list' => 'list',
    'list_all' => 'List all',
    'meta_description' => 'Meta Description',
    'meta_keywords' => 'Meta Keywords',
    'na' => 'N/A',
    'token_expiry' => 'You have until %s to make changes. After that time, the security token embedded into this page will expire and you will lose your changes.',
    'token_expired' => 'The security token for this operation has expired. Please authenticate again to continue.',
    'reauth_msg' => 'The security token for this operation has expired. If you want to continue with this operation, then please authenticate again below. This will ensure that the changes you just made will not be lost.',
    'authenticate' => 'Authenticate'
);

# Localisation of the texts for the various drop-down menus that are actually
# stored in the database. If these exist, they override the texts from the
# database.

$LANG_commentcodes = array(
    0 => 'Comments Enabled',
    -1 => 'Comments Disabled',
    1 => 'Comments Closed'
);

$LANG_commentmodes = array(
    'flat' => 'Flat',
    'nested' => 'Nested',
    'threaded' => 'Threaded',
    'nocomment' => 'No Comments'
);

$LANG_cookiecodes = array(
    0 => '(don\'t)',
    3600 => '1 Hour',
    7200 => '2 Hours',
    10800 => '3 Hours',
    28800 => '8 Hours',
    86400 => '1 Day',
    604800 => '1 Week',
    2678400 => '1 Month'
);

$LANG_dateformats = array(
    0 => 'System Default'
);

$LANG_featurecodes = array(
    0 => 'Not Featured',
    1 => 'Featured'
);

$LANG_frontpagecodes = array(
    0 => 'Show Only in Topic',
    1 => 'Show on Front Page'
);

$LANG_postmodes = array(
    'plaintext' => 'Plain Old Text',
    'html' => 'HTML Formatted'
);

$LANG_sortcodes = array(
    'ASC' => 'Oldest First',
    'DESC' => 'Newest First'
);

$LANG_trackbackcodes = array(
    0 => 'Trackback Enabled',
    -1 => 'Trackback Disabled'
);

###############################################################################
# Localization of the Admin Configuration UI

$LANG_CONFIG = array(
    'home' => 'Home',
    'admin_home' => 'Site Administration',
    'sections' => 'Configuration Sections',
    'restore' => 'Restore',
    'add_element' => 'Add Element',
    'save_changes' => 'Save Changes',
    'reset_form' => 'Reset Form',
    'changes_made' => 'Changes were successfully made to',
    'title' => 'Configuration Manager',
    'disable' => 'Click to disable this option',
    'enable' => 'Enable'
);

$LANG_configsections['Core'] = array(
    'label' => 'Geeklog',
    'title' => 'Geeklog Configuration'
);

$LANG_confignames['Core'] = array(
    'path_html' => 'HTML Path',
    'site_url' => 'Site URL',
    'site_admin_url' => 'Admin URL',
    'site_mail' => 'Site E-Mail',
    'noreply_mail' => 'No-Reply E-Mail',
    'site_name' => 'Site Name',
    'site_slogan' => 'Slogan',
    'microsummary_short' => 'Microsummary',
    'path_log' => 'Log',
    'path_language' => 'Language',
    'backup_path' => 'Backup',
    'path_data' => 'Data',
    'path_images' => 'Images',
    'path_pear' => 'Path Pear',
    'have_pear' => 'Have Pear?',
    'mail_settings' => 'Mail Settings',
    'allow_mysqldump' => 'Allow MySQL Dump',
    'mysqldump_path' => 'Path of Executable',
    'mysqldump_options' => 'MySQL Dump Options',
    'mysqldump_filename_mask' => 'Backup File Name Mask',
    'theme' => 'Theme',
    'doctype' => 'DOCTYPE Declaration',
    'menu_elements' => 'Menu Elements',
    'path_themes' => 'Themes Path',
    'disable_new_user_registration' => 'Disable New Registrations',
    'allow_user_themes' => 'Allow User Themes',
    'allow_user_language' => 'Allow User Language',
    'allow_user_photo' => 'Allow User Photo',
    'allow_username_change' => 'Allow Username Changes',
    'allow_account_delete' => 'Allow Account Deletion',
    'hide_author_exclusion' => 'Allow Hide Author',
    'show_fullname' => 'Show Fullname',
    'show_servicename' => 'Show Service Name',
    'custom_registration' => 'Enable Custom Registration',
    'user_login_method' => 'User Login Method',
    'spamx' => 'Spam-X Actions',
    'sort_admin' => 'Sort Links',
    'language' => 'Language',
    'locale' => 'Locale',
    'date' => 'Date Format',
    'daytime' => 'Daytime Format',
    'shortdate' => 'Short Date Format',
    'dateonly' => 'Date Only Format',
    'timeonly' => 'Time Only Format',
    'week_start' => 'Week Start',
    'hour_mode' => 'Hour Mode',
    'thousand_separator' => 'Thousands Separator',
    'decimal_separator' => 'Decimal Separator',
    'decimal_count' => 'Decimal Count',
    'language_files' => 'Language Files',
    'languages' => 'Languages',
    'timezone' => 'Timezone',
    'site_disabled_msg' => 'Site Disabled Message or URL',
    'rootdebug' => 'Root Debugging',
    'cookie_session' => 'Session Cookie Name',
    'cookie_name' => 'Permanent Cookie Name',
    'cookie_password' => 'Password Cookie Name',
    'cookie_theme' => 'Theme Cookie Name',
    'cookie_language' => 'Language Cookie Name',
    'cookie_tzid' => 'Timezone Cookie Name',
    'cookie_anon_name' => 'Anon. Username Cookie Name',
    'cookie_ip' => 'Cookies embed IP?',
    'default_perm_cookie_timeout' => 'Permanent Timeout',
    'session_cookie_timeout' => 'Session Timeout',
    'cookie_path' => 'Cookie Path',
    'cookiedomain' => 'Cookie Domain',
    'cookiesecure' => 'Cookie Secure',
    'lastlogin' => 'Record Last Login?',
    'num_search_results' => 'Number of Search Results',
    'loginrequired' => 'Login Required?',
    'submitloginrequired' => 'Submit Login Required?',
    'commentsloginrequired' => 'Comment Login Required?',
    'statsloginrequired' => 'Stats Login Required?',
    'searchloginrequired' => 'Search Login Required?',
    'profileloginrequired' => 'Profile Login Required?',
    'emailuserloginrequired' => 'E-Mail User Login Required?',
    'emailstoryloginrequired' => 'E-Mail Story Login Required?',
    'directoryloginrequired' => 'Directory Login Required?',
    'storysubmission' => 'Story Submission Queue?',
    'usersubmission' => 'User Submission Queue?',
    'listdraftstories' => 'List Draft Stories?',
    'notification' => 'Notifications',
    'postmode' => 'Default Post Mode',
    'speedlimit' => 'Post Speed Limit',
    'skip_preview' => 'Skip Preview in Posts',
    'advanced_editor' => 'Advanced Editor?',
    'wikitext_editor' => 'Wikitext Editor?',
    'cron_schedule_interval' => 'Cron Schedule Interval',
    'sortmethod' => 'Sort Topics',
    'showstorycount' => 'Show Story Count?',
    'showsubmissioncount' => 'Show Submission Count?',
    'hide_home_link' => 'Hide Home Link?',
    'whosonline_threshold' => 'Session Threshold',
    'whosonline_anonymous' => 'Hide Names from Guests?',
    'emailstories' => 'Daily Digest Enabled?',
    'emailstorieslength' => 'Length of Stories',
    'emailstoriesperdefault' => 'Enable for New Users?',
    'allow_domains' => 'Automatic Allow Domains',
    'disallow_domains' => 'Automatic Disallow Domains',
    'newstoriesinterval' => 'New Stories Interval',
    'newcommentsinterval' => 'New Comments Interval',
    'newtrackbackinterval' => 'New Trackbacks Interval',
    'hidenewstories' => 'Hide New Stories',
    'hidenewcomments' => 'Hide New Comments',
    'hidenewtrackbacks' => 'Hide New Trackbacks',
    'hidenewplugins' => 'Hide New Plugin Entries',
    'title_trim_length' => 'Title Trim Length',
    'trackback_enabled' => 'Trackback Enabled?',
    'pingback_enabled' => 'Pingback Enabled?',
    'ping_enabled' => 'Ping Enabled?',
    'trackback_code' => 'Trackback Default',
    'multiple_trackbacks' => 'Multiple Trackbacks',
    'trackbackspeedlimit' => 'Trackback Speed Limit',
    'check_trackback_link' => 'Check Trackbacks',
    'pingback_self' => 'Pingback Self?',
    'pingback_excerpt' => 'Create Pingback Excerpt?',
    'link_documentation' => 'Link to Documentation?',
    'link_versionchecker' => 'Link to Version Checker?',
    'maximagesperarticle' => 'Max Images per Article',
    'limitnews' => 'Stories per Page',
    'minnews' => 'Min. Stories per Page',
    'contributedbyline' => 'Show "Contributed By"?"',
    'hideviewscount' => 'Hide Views Count?',
    'hideemailicon' => 'Hide E-Mail Icon?',
    'hideprintericon' => 'Hide Print Icon?',
    'allow_page_breaks' => 'Allow Page Breaks?',
    'page_break_comments' => 'Comments on Multi-Page Articles',
    'article_image_align' => 'Topic Icon Alignment',
    'show_topic_icon' => 'Show Topic Icon?',
    'draft_flag' => 'Draft Flag Default',
    'frontpage' => 'Frontpage Default',
    'hide_no_news_msg' => 'Hide "No News" Message?',
    'hide_main_page_navigation' => 'Hide Main Page Navigation?',
    'onlyrootfeatures' => 'Only Root can Feature?',
    'aftersave_story' => 'After Saving Story',
    'aftersave_user' => 'After Saving User',
    'show_right_blocks' => 'Always Show Right Blocks?',
    'showfirstasfeatured' => 'Show First Story as Featured?',
    'backend' => 'Enable Feeds?',
    'rdf_file' => 'Syndication Output Folder',
    'rdf_limit' => 'Feed Limit',
    'rdf_storytext' => 'Length of Stories in Feed',
    'rdf_language' => 'Feed Language',
    'syndication_max_headlines' => 'Max. Number of Headlines (portal blocks)',
    'copyrightyear' => 'Copyright Year',
    'image_lib' => 'Image Library',
    'path_to_mogrify' => 'Path to Mogrify',
    'path_to_netpbm' => 'Path to Netpbm',
    'debug_image_upload' => 'Debug Image Uploading?',
    'keep_unscaled_image' => 'Keep Unscaled Image?',
    'allow_user_scaling' => 'Allow User Scaling?',
    'jpeg_quality' => 'JPEG Quality?',
    'max_image_width' => 'Max Image Width?',
    'max_image_height' => 'Max Image Height?',
    'max_image_size' => 'Max Image Size?',
    'max_topicicon_width' => 'Max Topic Icon Width?',
    'max_topicicon_height' => 'Max Topic Icon Height?',
    'max_topicicon_size' => 'Max Topic Icon Size?',
    'max_photo_width' => 'Max Photo Width?',
    'max_photo_height' => 'Max Photo Height?',
    'max_photo_size' => 'Max Photo Size?',
    'use_gravatar' => 'Use Gravatar?',
    'gravatar_rating' => 'Gravatar Rating',
    'force_photo_width' => 'Force Photo Width',
    'default_photo' => 'Default Photo',
    'commentspeedlimit' => 'Comment Speed Limit',
    'comment_limit' => 'Comment Limit',
    'comment_mode' => 'Comment Mode',
    'comment_code' => 'Comment Default',
    'comment_edit' => 'Allow Comment Edit?',
    'comment_edittime' => 'Comment Edit Time (seconds)',
    'commentsubmission' => 'Queue Comment Submissions',
    'passwordspeedlimit' => 'Password Speed Limit',
    'login_attempts' => 'Max. Login Attempts',
    'login_speedlimit' => 'Login Speed Limit',
    'user_html' => 'User HTML',
    'admin_html' => 'Admin HTML',
    'advanced_html' => 'Additional HTML for Adv. Editor',
    'skip_html_filter_for_root' => 'Skip HTML Filter for Root?',
    'allowed_protocols' => 'Allowed Protocols',
    'disable_autolinks' => 'Disable Autotags?',
    'clickable_links' => 'Make URLs clickable?',
    'compressed_output' => 'Send compressed output?',
    'frame_options' => 'Protection against "clickjacking"',
    'censormode' => 'Censor Mode?',
    'censorreplace' => 'Censor Replace Text',
    'censorlist' => 'Censor List',
    'ip_lookup' => 'IP Lookup',
    'url_rewrite' => 'Enable URL Rewrite',
    'meta_tags' => 'Meta Tags',
    'meta_description' => 'Default Meta Description',
    'meta_keywords' => 'Default Meta Keywords',
    'default_permissions_block' => 'Block Default Permissions',
    'default_permissions_story' => 'Story Default Permissions',
    'default_permissions_topic' => 'Topic Default Permissions',
    'atom_max_stories' => 'Max. Stories in Webservices Feed',
    'disable_webservices' => 'Disable Webservices?',
    'restrict_webservices' => 'Restrict Webservices?',
    'article_comment_close_enabled' => 'Automatically close comments (default)',
    'article_comment_close_days' => 'Days to close comments (default)',
    'comment_close_rec_stories' => 'Number of most recent stories enabled for comments',
    'allow_reply_notifications' => 'Allow comment reply notifications?',
    'search_style' => 'Results List Style',
    'search_limits' => 'Page Limits',
    'search_show_num' => 'Show Result Number?',
    'search_show_type' => 'Show Result Type?',
    'search_show_sort' => 'Allow User to Sort Results?',
    'search_show_limit' => 'Show Page Limits?',
    'search_separator' => 'Group Separator',
    'search_def_keytype' => 'Default Search Method',
    'search_def_sort' => 'Default Sort Order'
);

$LANG_configsubgroups['Core'] = array(
    'sg_site' => 'Site',
    'sg_stories' => 'Stories and Trackback',
    'sg_theme' => 'Theme',
    'sg_blocks' => 'Blocks',
    'sg_users' => 'Users and Submissions',
    'sg_images' => 'Images',
    'sg_locale' => 'Languages and Locale',
    'sg_misc' => 'Miscellaneous'
);

$LANG_fs['Core'] = array(
    'fs_site' => 'Site',
    'fs_paths' => 'Paths',
    'fs_theme' => 'Theme',
    'fs_mail' => 'Mail',
    'fs_pear' => 'Pear',
    'fs_mysql' => 'MySQL',
    'fs_users' => 'Users',
    'fs_misc' => 'Miscellaneous',
    'fs_spamx' => 'Spam-X',
    'fs_admin_block' => 'Admin Block',
    'fs_locale' => 'Locale',
    'fs_language' => 'Language',
    'fs_debug' => 'Debug',
    'fs_cookies' => 'Cookies',
    'fs_login' => 'Login Settings',
    'fs_search' => 'Search',
    'fs_user_submission' => 'User Submission',
    'fs_submission' => 'Submission Settings',
    'fs_topics_block' => 'Topics Block',
    'fs_whosonline_block' => 'Who\'s Online Block',
    'fs_daily_digest' => 'Daily Digest',
    'fs_whatsnew_block' => 'What\'s New Block',
    'fs_trackback' => 'Trackback',
    'fs_pingback' => 'Pingback',
    'fs_story' => 'Story',
    'fs_theme_advanced' => 'Advanced Settings',
    'fs_syndication' => 'Syndication',
    'fs_imagelib' => 'Image Library',
    'fs_upload' => 'Upload',
    'fs_articleimg' => 'Images in Articles',
    'fs_topicicon' => 'Topic Icons',
    'fs_userphoto' => 'Photos',
    'fs_gravatar' => 'Gravatar',
    'fs_comments' => 'Comments',
    'fs_htmlfilter' => 'HTML Filtering',
    'fs_censoring' => 'Censoring',
    'fs_iplookup' => 'IP Lookup',
    'fs_perm_story' => 'Story Default Permission',
    'fs_perm_topic' => 'Topic Default Permission',
    'fs_perm_block' => 'Block Default Permission',
    'fs_webservices' => 'Webservices'
);

$LANG_configselects['Core'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    2 => array('Reject' => 0, 'Only Keep Latest' => 1, 'Allow Multiple Posts' => 2),
    3 => array('Trackback Enabled' => 0, 'Trackback Disabled' => -1),
    4 => array('Don\'t Check Anything' => 0, 'Check against Site URL' => 1, 'Check full URL' => 2, 'Check against Site URL and full URL' => 3, 'Check IP against Site IP' => 4, 'Check IP and Site URL' => 5, 'Check IP and Full URL' => 6, 'Check IP, Full URL, and Site URL' => 7),
    5 => array('Plain Old Text' => 'plaintext', 'HTML Formatted' => 'html'),
    6 => array('12' => 12, '24' => 24),
    7 => array('Last Page' => 'last', 'First Page' => 'first', 'Every Page' => 'all'),
    8 => array('Right' => 'right', 'Left' => 'left'),
    9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    10 => array('None' => '', 'Netpbm' => 'netpbm', 'ImageMagick' => 'imagemagick', 'gdLib' => 'gdlib'),
    11 => array('Flat' => 'flat', 'Nested' => 'nested', 'Threaded' => 'threaded', 'No Comments' => 'nocomment'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3),
    13 => array('Skip' => 0, 'Allow, with speedlimit' => 1, 'Allow, no speedlimit' => 2),
    14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
    15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
    16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3),
    19 => array('Google' => 'google', 'Table' => 'table'),
    20 => array('Exact Phrase' => 'phrase', 'All of The Words' => 'all', 'Any of The Words' => 'any'),
    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2),
    24 => array('Contribute' => 'contribute', 'Home' => 'home', 'Advanced Search' => 'search', 'Directory' => 'directory', 'My Account' => 'prefs', 'Plugin Entries' => 'plugins', 'Custom Entries' => 'custom', 'Site Statistics' => 'stats'),
    25 => array('New Stories' => 'story', 'New Comments' => 'comment', 'New Trackbacks' => 'trackback', 'New Pingbacks' => 'pingback', 'New Users' => 'user'),
    26 => array('G (General Audiences)' => 'G', 'PG (Parental Guidance)' => 'PG', 'R (Restricted)' => 'R', 'X (Explicit)' => 'X'),
    27 => array('Hits (asc)' => 'hits|asc', 'Hits (desc)' => 'hits|desc', 'Date (asc)' => 'date|asc', 'Date (desc)' => 'date|desc', 'Title (asc)' => 'title|asc', 'Title (desc)' => 'title|desc', 'Author (asc)' => 'uid|asc', 'Author (desc)' => 'uid|desc')
);

?>
